@@ -9,9 +9,8 @@ from pycalphad import calculate
 from pycalphad.core.errors import EquilibriumError, ConditionError
 from pycalphad.core.starting_point import starting_point
 from pycalphad.codegen.callables import build_phase_records
-from pycalphad.core.constants import MIN_SITE_FRACTION
 from pycalphad.core.eqsolver import _solve_eq_at_conditions
-from pycalphad.core.solver import InteriorPointSolver
+from pycalphad.core.solver import Solver
 from pycalphad.core.light_dataset import LightDataset
 import numpy as np
 from collections import OrderedDict
@@ -21,18 +20,24 @@ from datetime import datetime
 def _adjust_conditions(conds):
     "Adjust conditions values to be within the numerical limit of the solver."
     new_conds = OrderedDict()
+    minimum_composition = 1e-10
     for key, value in sorted(conds.items(), key=str):
         if key == str(key):
             key = getattr(v, key, key)
         if isinstance(key, v.MoleFraction):
-            new_conds[key] = [max(val, MIN_SITE_FRACTION*1000) for val in unpack_condition(value)]
+            vals = unpack_condition(value)
+            # "Zero" composition is a common pattern. Do not warn for that case.
+            if np.any(np.logical_and(np.asarray(vals) < minimum_composition, np.asarray(vals) > 0)):
+                warnings.warn(
+                    f"Some specified compositions are below the minimum allowed composition of {minimum_composition}.")
+            new_conds[key] = [max(val, minimum_composition) for val in vals]
         else:
             new_conds[key] = unpack_condition(value)
     return new_conds
 
 
-def _eqcalculate(dbf, comps, phases, conditions, output, data=None, per_phase=False, callables=None, parameters=None,
-                 **kwargs):
+def _eqcalculate(dbf, comps, phases, conditions, output, data=None, per_phase=False, callables=None, model=None,
+                 parameters=None, **kwargs):
     """
     WARNING: API/calling convention not finalized.
     Compute the *equilibrium value* of a property.
@@ -56,20 +61,20 @@ def _eqcalculate(dbf, comps, phases, conditions, output, data=None, per_phase=Fa
     output : str
         Equilibrium model property (e.g., CPM, HM, etc.) to compute.
         This must be defined as an attribute in the Model class of each phase.
-    data : Dataset, optional
+    data : Dataset
         Previous result of call to `equilibrium`.
         Should contain the equilibrium configurations at the conditions of interest.
         If the databases are not the same as in the original calculation,
-        the results may be meaningless. If None, `equilibrium` will be called.
-        Specifying this keyword argument can save the user some time if several properties
-        need to be calculated in succession.
+        the results may be meaningless.
     per_phase : bool, optional
         If True, compute and return the property for each phase present.
         If False, return the total system value, weighted by the phase fractions.
-    parameters : dict, optional
-        Maps SymPy Symbol to numbers, for overriding the values of parameters in the Database.
     callables : dict
         Callable functions to compute 'output' for each phase.
+    model : a dict of phase names to Model
+        Model class to use for each phase.
+    parameters : dict, optional
+        Maps SymPy Symbol to numbers, for overriding the values of parameters in the Database.
     kwargs
         Passed to `calculate`.
 
@@ -78,8 +83,10 @@ def _eqcalculate(dbf, comps, phases, conditions, output, data=None, per_phase=Fa
     Dataset of property as a function of equilibrium conditions
     """
     if data is None:
-        data = equilibrium(dbf, comps, phases, conditions, to_xarray=False)
-    active_phases = unpack_phases(phases) or sorted(dbf.phases.keys())
+        raise ValueError('Required kwarg "data" is not specified')
+    if model is None:
+        raise ValueError('Required kwarg "model" is not specified')
+    active_phases = unpack_phases(phases)
     conds = _adjust_conditions(conditions)
     indep_vars = ['N', 'P', 'T']
     # TODO: Rewrite this to use the coord dict from 'data'
@@ -101,7 +108,7 @@ def _eqcalculate(dbf, comps, phases, conditions, output, data=None, per_phase=Fa
     # For each phase select all conditions where that phase exists
     # Perform the appropriate calculation and then write the result back
     for phase in active_phases:
-        dof = sum([len(x) for x in dbf.phases[phase].constituents])
+        dof = len(model[phase].site_fractions)
         current_phase_indices = (data.Phase == phase)
         if ~np.any(current_phase_indices):
             continue
@@ -113,7 +120,7 @@ def _eqcalculate(dbf, comps, phases, conditions, output, data=None, per_phase=Fa
         if statevars.get('mode', None) is None:
             statevars['mode'] = 'numpy'
         calcres = calculate(dbf, comps, [phase], output=output, points=points, broadcast=False,
-                            callables=callables, parameters=parameters, **statevars)
+                            callables=callables, parameters=parameters, model=model, **statevars)
         result[output][np.nonzero(current_phase_indices)] = calcres[output].values
     if not per_phase:
         out = np.nansum(result[output] * data['NP'], axis=-1)
@@ -170,7 +177,7 @@ def equilibrium(dbf, comps, phases, conditions, output=None, model=None,
         Maps SymPy Symbol to numbers, for overriding the values of parameters in the Database.
     solver : pycalphad.core.solver.SolverBase
         Instance of a solver that is used to calculate local equilibria.
-        Defaults to a pycalphad.core.solver.InteriorPointSolver.
+        Defaults to a pycalphad.core.solver.Solver.
     callables : dict, optional
         Pre-computed callable functions for equilibrium calculation.
 
@@ -189,7 +196,7 @@ def equilibrium(dbf, comps, phases, conditions, output=None, model=None,
     list_of_possible_phases = filter_phases(dbf, comps)
     if len(list_of_possible_phases) == 0:
         raise ConditionError('There are no phases in the Database that can be active with components {0}'.format(comps))
-    active_phases = {name: dbf.phases[name] for name in filter_phases(dbf, comps, phases)}
+    active_phases = filter_phases(dbf, comps, phases)
     if len(active_phases) == 0:
         raise ConditionError('None of the passed phases ({0}) are active. List of possible phases: {1}.'.format(phases, list_of_possible_phases))
     if isinstance(comps, (str, v.Species)):
@@ -198,7 +205,7 @@ def equilibrium(dbf, comps, phases, conditions, output=None, model=None,
         raise EquilibriumError('Components not found in database: {}'
                                .format(','.join([c.name for c in (set(comps) - set(dbf.species))])))
     calc_opts = calc_opts if calc_opts is not None else dict()
-    solver = solver if solver is not None else InteriorPointSolver(verbose=verbose)
+    solver = solver if solver is not None else Solver(verbose=verbose)
     parameters = parameters if parameters is not None else dict()
     if isinstance(parameters, dict):
         parameters = OrderedDict(sorted(parameters.items(), key=str))
@@ -240,8 +247,9 @@ def equilibrium(dbf, comps, phases, conditions, output=None, model=None,
     grid_opts = calc_opts.copy()
     statevar_strings = [str(x) for x in state_variables]
     grid_opts.update({key: value for key, value in str_conds.items() if key in statevar_strings})
+
     if 'pdens' not in grid_opts:
-        grid_opts['pdens'] = 500
+        grid_opts['pdens'] = 50
     grid = calculate(dbf, comps, active_phases, model=models, fake_points=True,
                      callables=callables, output='GM', parameters=parameters,
                      to_xarray=False, **grid_opts)
