@@ -1,6 +1,8 @@
 """
 The utils module handles helper routines for equilibrium calculation.
 """
+import warnings
+
 import pycalphad.variables as v
 from pycalphad.core.halton import halton
 from pycalphad.core.constants import MIN_SITE_FRACTION
@@ -13,14 +15,6 @@ import itertools
 import collections
 from collections.abc import Iterable, Mapping
 
-try:
-    # Only available in numpy 1.10 and newer
-    from numpy import broadcast_to
-except ImportError:
-    def broadcast_to(arr, shape):
-        "Broadcast an array to a desired shape. Returns a view."
-        return np.broadcast_arrays(arr, np.empty(shape, dtype=np.bool))[0]
-
 
 def point_sample(comp_count, pdof=10):
     """
@@ -131,9 +125,9 @@ def unpack_condition(tup):
         if len(tup) == 1:
             return [float(tup[0])]
         elif len(tup) == 2:
-            return np.arange(tup[0], tup[1], dtype=np.float)
+            return np.arange(tup[0], tup[1], dtype=np.float_)
         elif len(tup) == 3:
-            return np.arange(tup[0], tup[1], tup[2], dtype=np.float)
+            return np.arange(tup[0], tup[1], tup[2], dtype=np.float_)
         else:
             raise ValueError('Condition tuple is length {}'.format(len(tup)))
     elif isinstance(tup, Iterable):
@@ -147,8 +141,7 @@ def unpack_phases(phases):
     if isinstance(phases, (list, tuple, set)):
         active_phases = sorted(phases)
     elif isinstance(phases, dict):
-        active_phases = sorted([phn for phn, status in phases.items() \
-            if status == 'entered'])
+        active_phases = sorted(phases.keys())
     elif type(phases) is str:
         active_phases = [phases]
     return active_phases
@@ -158,6 +151,10 @@ def generate_dof(phase, active_comps):
     Accept a Phase object and a set() of the active components.
     Return a tuple of variable names and the sublattice degrees of freedom.
     """
+    msg = "generate_dof is deprecated and will be removed in a future version "
+    msg += "of pycalphad. The correct way to determine the degrees of freedom "
+    msg += "of a particular 'active' phase is to use Model.constituents."
+    warnings.warn(msg, FutureWarning)
     variables = []
     sublattice_dof = []
     for idx, sublattice in enumerate(phase.constituents):
@@ -187,7 +184,7 @@ def endmember_matrix(dof, vacancy_indices=None):
     >>> endmember_matrix([3,3,1], vacancy_indices=[[2], [2], [0]])
     """
     total_endmembers = functools.reduce(operator.mul, dof, 1)
-    res_matrix = np.empty((total_endmembers, sum(dof)), dtype=np.float)
+    res_matrix = np.empty((total_endmembers, sum(dof)), dtype=np.float_)
     dof_arrays = [np.eye(d).tolist() for d in dof]
     row_idx = 0
     for row in itertools.product(*dof_arrays):
@@ -365,12 +362,15 @@ def extract_parameters(parameters):
     Returns
     -------
     tuple
-        Tuple of parameter symbols and parameter values
+        Tuple of parameter symbols (list) and parameter values (parameter_array_length, # parameters)
     """
+    parameter_array_lengths = set(np.atleast_1d(val).size for val in parameters.values())
+    if len(parameter_array_lengths) > 1:
+        raise ValueError('parameters kwarg does not contain arrays of equal length')
     if len(parameters) > 0:
         param_symbols, param_values = zip(*[(wrap_symbol(key), val) for key, val in sorted(parameters.items(),
                                                                               key=operator.itemgetter(0))])
-        param_values = np.asarray(param_values, dtype=np.float64)
+        param_values = np.atleast_2d(np.ascontiguousarray(np.asarray(param_values, dtype=np.float64).T))
     else:
         param_symbols = []
         param_values = np.empty(0)
